package com.care.bigscreen.controller;


import com.care.bigscreen.service.BigScreenService;
import com.care.bigscreen.vo.*;

import com.care.common.vo.PageResVO;
import com.care.util.PageResult;
import com.care.util.PageUtil;
import com.care.util.Result;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * @author javadoc
 * @version 1.0
 * @description 大屏控制器
 * @date
 */
@Slf4j
@RestController
@RequestMapping("/bms/bigscreen")
public class BigScreenController {

    @Autowired
    private BigScreenService bigScreenService;


    /**
     * 运营商大屏统计查询
     */
    @ApiOperation(value = "运营商大屏统计查询", notes = "运营商大屏统计查询")
    @GetMapping("/selectBigScreenStatisticsByOp")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "header", required = true, name = "token", dataType = "String", value = "token验证信息")
    })
    public Result<BigScreenStatisticsVO> selectBigScreenStatisticsByOp(@RequestHeader("token") String token) {
        try {
            BigScreenStatisticsVO bigScreenStatisticsVO =  bigScreenService.selectBigScreenStatistics(null,null);
            return Result.success(bigScreenStatisticsVO);
        } catch (Exception e) {
           log.error("运营商大屏统计查询出现异常",e);
            return Result.error("系统错误，运营商大屏统计查询失败");
        }
    }

    /**
     * 机构大屏统计查询
     */
    @ApiOperation(value = "机构大屏统计查询", notes = "机构大屏统计查询")
    @GetMapping("/selectBigScreenStatisticsByOrg")
    @ApiImplicitParams(
            {
                    @ApiImplicitParam(paramType = "header", required = true, name = "token", dataType = "String", value = "token验证信息"),
                    @ApiImplicitParam(name = "orgId", value = "机构ID", dataTypeClass = Long.class,required = true)
            }
    )
    public Result<BigScreenStatisticsVO> selectBigScreenStatisticsByOrg(@RequestHeader("token") String token,Long orgId) {
        try {
            BigScreenStatisticsVO bigScreenStatisticsVO =  bigScreenService.selectBigScreenStatistics(null,orgId);
            return Result.success(bigScreenStatisticsVO);
        } catch (Exception e) {
            log.error("机构大屏统计查询异常",e);
            return Result.error("系统错误，机构大屏统计查询失败");
        }
    }

    /**
     * 运营商大屏或机构大屏的站点统计查询
     */
    @ApiOperation(value = "运营商大屏或机构大屏的站点统计查询", notes = "运营商大屏或机构大屏的站点统计查询")
    @GetMapping("/selectBigScreenStatisticsByStation")
    @ApiImplicitParams(
            {
                    @ApiImplicitParam(paramType = "header", required = true, name = "token", dataType = "String", value = "token验证信息"),
                    @ApiImplicitParam(name = "stationId", value = "站点ID", dataTypeClass = Long.class,required = true)
            }
    )
    public Result<BigScreenStatisticsVO> selectBigScreenStatisticsByStation(@RequestHeader("token") String token,Long stationId) {
        try {
            BigScreenStatisticsVO bigScreenStatisticsVO =  bigScreenService.selectBigScreenStatistics(stationId,null);
            return Result.success(bigScreenStatisticsVO);
        } catch (Exception e) {
            log.error("运营商大屏或机构大屏的站点统计查询出现异常",e);
            return Result.error("系统错误，运营商大屏或机构大屏的站点统计查询失败");
        }
    }

    /**
     * 运营商大屏或机构大屏的根据经纬度查询统计值
     */
    @ApiOperation(value = "运营商大屏或机构大屏的根据经纬度查询统计值", notes = "运营商大屏或机构大屏的根据经纬度查询统计值")
    @GetMapping("/selectBigScreenStatisticsByLongitudeLatitude")
    @ApiImplicitParams(
            {
                    @ApiImplicitParam(paramType = "header", required = true, name = "token", dataType = "String", value = "token验证信息"),
                    @ApiImplicitParam(name = "longitudeLeftUp", value = "左上经度", dataTypeClass = String.class,required = true),
                    @ApiImplicitParam(name = "latitudeLeftUp", value = "左上维度", dataTypeClass = String.class,required = true),
                    @ApiImplicitParam(name = "longitudeRightDown", value = "右下经度", dataTypeClass = String.class,required = true),
                    @ApiImplicitParam(name = "latitudeRightDown", value = "右下维度", dataTypeClass = String.class,required = true),
                    @ApiImplicitParam(name = "orgId", value = "机构ID", dataTypeClass = Long.class,required = false)
            }
    )
    public Result<BigScreenStatisticsVO> selectBigScreenStatisticsByLongitudeLatitude(@RequestHeader("token") String token,String longitudeLeftUp, String latitudeLeftUp,String longitudeRightDown,String latitudeRightDown,Long orgId) {
        try {
            BigScreenStatisticsVO bigScreenStatisticsVO =  bigScreenService.selectBigScreenStatisticsByLongitudeLatitude(longitudeLeftUp,latitudeLeftUp,longitudeRightDown,latitudeRightDown,orgId);
            return Result.success(bigScreenStatisticsVO);
        } catch (Exception e) {
            log.error("运营商大屏或机构大屏的根据经纬度查询统计值出现异常",e);
            return Result.error("系统错误，运营商大屏或机构大屏的根据经纬度查询统计值失败");
        }
    }

    /**
     * 运营商大屏或机构大屏的站点列表查询
     */
    @ApiOperation(value = "运营商大屏或机构大屏的站点列表查询", notes = "运营商大屏或机构大屏的站点列表查询")
    @GetMapping("/selectBigScreenStationList")
    @ApiImplicitParams(
            {
                    @ApiImplicitParam(paramType = "header", required = true, name = "token", dataType = "String", value = "token验证信息"),
                    @ApiImplicitParam(name = "orgId", value = "机构ID", dataTypeClass = Long.class,required = false)
            }
    )
    public Result<List<BigScreenStationVO>> selectBigScreenStationList(@RequestHeader("token") String token,Long orgId) {
        try {
            List<BigScreenStationVO> bigScreenStationVOList =  bigScreenService.selectBigScreenStationList(orgId);
            return Result.success(bigScreenStationVOList);
        } catch (Exception e) {
            log.error("运营商大屏或机构大屏的站点列表查询出现异常",e);
            return Result.error("系统错误，运营商大屏或机构大屏的站点列表查询失败");
        }
    }

    /**
     * 机构大屏的站点列表用户数TOP5查询
     */
    @ApiOperation(value = "机构大屏的站点列表用户数TOP5查询", notes = "机构大屏的站点列表用户数TOP5查询")
    @GetMapping("/selectBigScreenStationListOlderTop5")
    @ApiImplicitParams(
            {
                    @ApiImplicitParam(paramType = "header", required = true, name = "token", dataType = "String", value = "token验证信息"),
                    @ApiImplicitParam(name = "orgId", value = "机构ID", dataTypeClass = Long.class,required = true)
            }
    )
    public Result<List<BigScreenStationVO>> selectBigScreenStationListOlderTop5(@RequestHeader("token") String token,Long orgId) {
        try {
            List<BigScreenStationVO> bigScreenStationVOList =  bigScreenService.selectBigScreenStationListOlderTop5(orgId);
            return Result.success(bigScreenStationVOList);
        } catch (Exception e) {
            log.error("机构大屏的站点列表用户数TOP5查询出现异常",e);
            return Result.error("系统错误，机构大屏的站点列表用户数TOP5查询失败");
        }
    }

    /**
     * 机构大屏的站点列表安全事件TOP5查询
     */
    @ApiOperation(value = "机构大屏的站点列表安全事件TOP5查询", notes = "机构大屏的站点列表安全事件TOP5查询")
    @GetMapping("/selectBigScreenStationListEventTop5")
    @ApiImplicitParams(
            {
                    @ApiImplicitParam(paramType = "header", required = true, name = "token", dataType = "String", value = "token验证信息"),
                    @ApiImplicitParam(name = "orgId", value = "机构ID", dataTypeClass = Long.class,required = true)
            }
    )
    public Result<List<BigScreenStationVO>> selectBigScreenStationListEventTop5(@RequestHeader("token") String token,Long orgId) {
        try {
            List<BigScreenStationVO> bigScreenStationVOList =  bigScreenService.selectBigScreenStationListEventTop5(orgId);
            return Result.success(bigScreenStationVOList);
        } catch (Exception e) {
            log.error("机构大屏的站点列表安全事件TOP5查询出现异常",e);
            return Result.error("系统错误，机构大屏的站点列表安全事件TOP5查询失败");
        }
    }

    /**
     * 服务站大屏的站点统计查询
     */
    @ApiOperation(value = "服务站大屏的站点统计查询", notes = "服务站大屏的站点统计查询")
    @GetMapping("/selectStationBigScreenStatisticsByStation")
    @ApiImplicitParams(
            {
                    @ApiImplicitParam(paramType = "header", required = true, name = "token", dataType = "String", value = "token验证信息"),
                    @ApiImplicitParam(name = "stationId", value = "站点ID", dataTypeClass = Long.class,required = true)
            }
    )
    public Result<BigScreenStationStatisticsVO> selectStationBigScreenStatisticsByStation(@RequestHeader("token") String token,Long stationId) {
        try {
            BigScreenStationStatisticsVO bigScreenStationStatisticsVO =  bigScreenService.selectStationBigScreenStatisticsByStation(stationId);
            return Result.success(bigScreenStationStatisticsVO);
        } catch (Exception e) {
            log.error("服务站大屏的站点统计查询出现异常",e);
            return Result.error("系统错误，服务站大屏的站点统计查询失败");
        }
    }


    /**
     * 服务站大屏的告警用户列表查询
     */
    @ApiOperation(value = "服务站大屏的告警用户列表查询", notes = "服务站大屏的告警用户列表查询")
    @GetMapping("/selectBigScreenAlarmOlderList")
    @ApiImplicitParams(
            {
                    @ApiImplicitParam(paramType = "header", required = true, name = "token", dataType = "String", value = "token验证信息"),
                    @ApiImplicitParam(name = "stationId", value = "站点ID", dataTypeClass = Long.class,required = true),
                    @ApiImplicitParam(name = "olderName", value = "被监护人姓名", dataTypeClass = String.class,required = false)
            }
    )
    public Result<List<BigScreenAlarmOlderVO>> selectBigScreenAlarmOlderList(@RequestHeader("token") String token,Long stationId,String olderName) {
        try {
            List<BigScreenAlarmOlderVO> bigScreenAlarmOlderVOList =  bigScreenService.selectBigScreenAlarmOlderList(stationId,olderName);
            return Result.success(bigScreenAlarmOlderVOList);
        } catch (Exception e) {
            log.error("告警用户列表查询出现异常",e);
            return Result.error("系统错误，告警用户列表查询失败");
        }
    }


    /**
     * 服务站大屏的被监控人详细查询
     */
    @ApiOperation(value = "服务站大屏的被监控人详细查询", notes = "服务站大屏的被监控人详细查询")
    @GetMapping("/selectStationBigScreenOlderDetail")
    @ApiImplicitParams(
            {
                    @ApiImplicitParam(paramType = "header", required = true, name = "token", dataType = "String", value = "token验证信息"),
                    @ApiImplicitParam(name = "olderId", value = "被监护人ID", dataTypeClass = Long.class,required = true)
            }
    )
    public Result<BigScreenOlderDetailVO> selectStationBigScreenOlderDetail(@RequestHeader("token") String token,Long olderId) {
        try {
            BigScreenOlderDetailVO bigScreenOlderDetailVO =  bigScreenService.selectStationBigScreenOlderDetail(olderId);
            return Result.success(bigScreenOlderDetailVO);
        } catch (Exception e) {
            log.error("服务站大屏的被监控人详细查询出现异常",e);
            return Result.error("系统错误，服务站大屏的被监控人详细查询失败");
        }
    }

    /**
     * 服务站大屏的实时安全事件列表查询
     */
    @ApiOperation(value = "服务站大屏的实时安全事件列表查询", notes = "服务站大屏的实时安全事件列表查询")
    @GetMapping("/selectBigScreenRtEventList")
    @ApiImplicitParams(
            {
                    @ApiImplicitParam(paramType = "header", required = true, name = "token", dataType = "String", value = "token验证信息"),
                    @ApiImplicitParam(name = "stationId", value = "站点ID", dataTypeClass = Long.class,required = true)
            }
    )
    public Result<List<BigScreenEventVO>> selectBigScreenRtEventList(@RequestHeader("token") String token,Long stationId) {
        try {
            List<BigScreenEventVO> bigScreenEventVOList =  bigScreenService.selectBigScreenRtEventList(stationId);
            return Result.success(bigScreenEventVOList);
        } catch (Exception e) {
            log.error("告警用户列表查询出现异常",e);
            return Result.error("系统错误，告警用户列表查询失败");
        }
    }

    /**
     * 服务站大屏的已完成安全事件列表分页查询
     */
    @ApiOperation(value = "服务站大屏的已完成安全事件列表分页查询", notes = "服务站大屏的已完成安全事件列表分页查询")
    @GetMapping("/selectBigScreenHisEventListByPage")
    @ApiImplicitParams(
            {
                    @ApiImplicitParam(paramType = "header", required = true, name = "token", dataType = "String", value = "token验证信息"),
                    @ApiImplicitParam(name = "stationId", value = "站点ID", dataTypeClass = Long.class,required = true)
            }
    )
    public PageResult<List<BigScreenEventVO>> selectBigScreenHisEventListByPage(@RequestHeader("token") String token,Long stationId, PageResVO page) {
        try {
            PageUtil<BigScreenEventVO> bigScreenEventVOListByPage =  bigScreenService.selectBigScreenHisEventListByPage(stationId,page);
            return  PageResult.success(
                    "查询成功",bigScreenEventVOListByPage.getListT(),
                    bigScreenEventVOListByPage.getCurrent(),
                    bigScreenEventVOListByPage.getPageSize(),
                    bigScreenEventVOListByPage.getTotal());
        } catch (Exception e) {
            log.error("服务站大屏的已完成安全事件列表分页查询出现异常",e);
            return PageResult.error("系统错误，服务站大屏的已完成安全事件列表分页查询失败");
        }
    }

    /**
     * 服务站大屏的用户卡片列表分页查询
     */
    @ApiOperation(value = "服务站大屏的用户卡片列表分页查询", notes = "服务站大屏的用户卡片列表分页查询")
    @GetMapping("/selectBigScreenOlderCardListByPage")
    @ApiImplicitParams(
            {
                    @ApiImplicitParam(paramType = "header", required = true, name = "token", dataType = "String", value = "token验证信息"),
                    @ApiImplicitParam(name = "stationId", value = "站点ID", dataTypeClass = Long.class,required = true),
                    @ApiImplicitParam(name = "olderName", value = "被监护人姓名", dataTypeClass = String.class,required = false)
            }
    )
    public PageResult<List<BigScreenOlderDetailVO>> selectBigScreenOlderCardListByPage(@RequestHeader("token") String token,Long stationId,String olderName, PageResVO page) {
        try {
            PageUtil<BigScreenOlderDetailVO> bigScreenOlderDetailVOList =  bigScreenService.selectBigScreenOlderCardListByPage(stationId,olderName,page);
            return  PageResult.success(
                    "查询成功",bigScreenOlderDetailVOList.getListT(),
                    bigScreenOlderDetailVOList.getCurrent(),
                    bigScreenOlderDetailVOList.getPageSize(),
                    bigScreenOlderDetailVOList.getTotal());
        } catch (Exception e) {
            log.error("服务站大屏的用户卡片列表分页查询出现异常",e);
            return PageResult.error("系统错误，服务站大屏的用户卡片列表分页查询失败");
        }
    }
}
